@@ -73,6 +73,8 @@ class ImagesEndpoint:
                    ra_max: Optional[float] = None,
                    dec_min: Optional[float] = None,
                    dec_max: Optional[float] = None,
+                   obsdate_min: Optional[str] = None,
+                   obsdate_max: Optional[str] = None,
                    **kwargs) -> List[Dict[str, Any]]:
         url = f"{self.base_url}/adss/v1/images/collections/{collection_id}/files"
         try:
@@ -91,7 +93,11 @@ class ImagesEndpoint:
             params.update({"ra": ra, "dec": dec, "radius": radius})
         if ra_min is not None and ra_max is not None and dec_min is not None and dec_max is not None:
             params.update({"ra_min": ra_min, "ra_max": ra_max, "dec_min": dec_min, "dec_max": dec_max})
-
+        if obsdate_min is not None:
+            params["obsdate_min"] = obsdate_min
+        if obsdate_max is not None:
+            params["obsdate_max"] = obsdate_max
+        print(obsdate_min)
         try:
             resp = self.auth_manager.request(
                 method="GET",
@@ -160,7 +166,7 @@ class ImagesEndpoint:
                 with open(output_path, 'wb') as f:
                     for chunk in resp.iter_content(8192):
                         f.write(chunk)
-                return output_path
+                return resp.read()
             return resp.read()
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to download image file {file_id}: {e}")
@@ -660,7 +666,7 @@ class StampImagesEndpoint:
         with open(final_path, "wb") as f:
             f.write(data)
 
-        return final_path
+        return data
 
 
 class TrilogyImagesEndpoint:
@@ -769,7 +775,7 @@ class TrilogyImagesEndpoint:
             if output_path:
                 with open(output_path, 'wb') as f:
                     f.write(resp.read())
-                return output_path
+                return resp.read()
             return resp.read()
 
         except Exception as e:
